@@ -1,6 +1,6 @@
 
 (*
- * Copyright (C) 2007-2009 The laby team
+ * Copyright (C) 2007-2010 The laby team
  * You have permission to copy, modify, and redistribute under the
  * terms of the GPL-3.0. For full license terms, see gpl-3.0.txt.
  *)
@@ -12,8 +12,7 @@ val version_current : string
 val version_base : string
 val version_status : string
 
+val build_system : string
+val build_arch : string
 val build_ocaml : string
 val build_lablgtk : string
-
-val conf_path : string
-val sys_data_path : string
