@@ -1,9 +1,10 @@
 #!/bin/sh
 
+
 if [ -d "_MTN" ] && mtn automate get_workspace_root 2> /dev/null > /dev/null
 then
-VERSION_BASE=$(mtn automate get_base_revision_id)
-VERSION_CURRENT=$(mtn automate get_current_revision_id)
+VERSION_BASE=$(mtn automate get_base_revision_id 2> /dev/null)
+VERSION_CURRENT=$(mtn automate get_current_revision_id 2> /dev/null)
 VERSION_STATUS=$(mtn diff | grep ^# | sed 's/"/\\"/g')
 else
 VERSION_BASE="unknown"
@@ -23,8 +24,10 @@ let version_base = "${VERSION_BASE}"
 let version_current = "${VERSION_CURRENT}"
 let version_status = "${VERSION_STATUS}"
 
+let build_system = "${OCAML_SYSTEM}"
+let build_arch = "${OCAML_ARCH}"
 let build_ocaml = "${OCAML_VERSION}"
 let build_lablgtk = "${BUILD_LABLGTK}"
-let conf_path = Sys.getenv "HOME" ^ "/.config/${PROJECT_NAME}/"
-let sys_data_path = "${SYSDATADIR}/${PROJECT_NAME}/"
+let _ = Res.sys_data_dir := "${SYSDATADIR}"
+let _ = Res.sys_tmp_dir := "${SYSTMPDIR}"
 EOF
