@@ -1,5 +1,5 @@
 (*
-   Copyright (C) 2007-2009 Stéphane Gimenez
+   Copyright (C) 2007-2010 Stéphane Gimenez
    You have permission to copy, modify, and redistribute under the
    terms of the GPL-3.0. For full license terms, see gpl-3.0.txt.
 *)
@@ -30,10 +30,12 @@ let opt_daemon =
     (F.x "run in daemon mode" [])
 
 
+let log = Log.make []
+
 exception Signal of int
 
 let signal i =
-  Log.master#debug 1 (
+  log#debug 1 (
     F.x "received signal <number>" [
       "number", F.int i;
     ]
@@ -73,7 +75,7 @@ let daemonize () =
 
 let exit_when_root () =
   let security s =
-    Log.master#fatal (
+    log#fatal (
       F.x "security exit: <msg>" [
 	"msg", F.string s;
       ]
@@ -83,46 +85,51 @@ let exit_when_root () =
   if Unix.geteuid () = 0 then security "root euid";
   if Unix.getegid () = 0 then security "root egid"
 
-let init ?(prohibit_root=false) ?path ?conf ?services action =
+let init ?(prohibit_root=false) ?name ?conf ?services action =
   if prohibit_root then exit_when_root ();
-  Res.conf_paths#set_d path;
+  Res.conf_domain#set_d name;
   begin match conf with
   | None -> ()
   | Some (conf, res) ->
       begin try
-	Conf.load ~log:Log.master#warning conf (Res.get res)
+	Conf.load ~log:log#warning conf (Res.get res)
       with
       | Res.Error msg ->
-	  Log.master#fatal msg;
+	  log#fatal msg;
 	  exit 3
       end
   end;
-  let f () =
+  let f =
     begin match action with
-    | `Main f -> f ()
+    | `Main f -> f
     | `Opts (opts, proceed) ->
 	begin match Opt.cmd opts with
 	| `Errors ml ->
-	    Log.master#error (
-	      F.x "invalid options: <errors>" [
-		"errors", F.v ml;
-	      ]
-	    ) ;
-	    exit 1;
+	    begin fun () ->
+	      log#error (
+		F.x "invalid options: <errors>" [
+		  "errors", F.v ml;
+		]
+	      );
+	      exit 1
+	    end
 	| `Excl fn ->
-	    Fd.stdout (fn ());
-	    exit 0;
+	    (fun () -> Fd.stdout (fn ()))
 	| `Proceed list ->
-	    proceed list
+	    (fun () -> proceed list)
 	end
     end
   in
   Sys.catch_break true;
-  Sys.set_signal Sys.sigpipe (Sys.Signal_handle signal);
+  begin match Sys.os_type with
+  | "Unix" ->
+      Sys.set_signal Sys.sigpipe (Sys.Signal_handle signal);
+      Sys.set_signal Sys.sigquit (Sys.Signal_handle signal);
+      Sys.set_signal Sys.sigalrm (Sys.Signal_handle signal);
+      Sys.set_signal Sys.sighup Sys.Signal_ignore;
+  | _ -> ()
+  end;
   Sys.set_signal Sys.sigterm (Sys.Signal_handle signal);
-  Sys.set_signal Sys.sigquit (Sys.Signal_handle signal);
-  Sys.set_signal Sys.sigalrm (Sys.Signal_handle signal);
-  Sys.set_signal Sys.sighup Sys.Signal_ignore;
   let clean =
     begin match conf_daemon#get with
     | false -> fun () -> ()
@@ -133,49 +140,58 @@ let init ?(prohibit_root=false) ?path ?conf ?services action =
     Srv.launch ?services f
   with
   | Fail msg ->
+      log#fatal msg;
       clean ();
       exit 2
   | Res.Error msg ->
-      Log.master#fatal msg;
+      log#fatal msg;
       clean ();
       exit 3
   | Signal i when i = Sys.sigterm || i = Sys.sigquit -> ()
   | Sys.Break -> ()
   | Srv.StartError (e) ->
-      Log.master#internal (
-	F.x "exception encountered during start phase: <exn>"
-	  ["exn", F.v [F.exn e]]
+      let bt = Printexc.get_backtrace () in
+      log#internal (
+	F.x "exception in start phase: <exn>"
+	  ["exn", F.exn ~bt e]
       );
-      clean ();
-      raise e
   | Srv.StopError (e) ->
-      Log.master#internal (
-	F.x "exception encountered during stop phase: <exn>"
-	  ["exn", F.v [F.exn e]]
+      let bt = Printexc.get_backtrace () in
+      log#internal (
+	F.x "exception in stop phase: <exn>"
+	  ["exn", F.exn ~bt e]
       );
-      clean ();
-      raise e
   | e ->
-      Log.master#internal (
+      let bt = Printexc.get_backtrace () in
+      log#internal (
 	F.x "exception: <exn>"
-	  ["exn", F.v [F.exn e]]
+	  ["exn", F.exn ~bt e]
       );
-      clean ();
-      raise e
   end;
   clean ()
 
 let fatal msg =
-  Log.master#fatal msg;
   raise (Fail msg)
 
+let error msg =
+  log#error msg
+
+let warning msg =
+  log#warning msg
+
+let info msg =
+  log#info msg
+
+let report f =
+  log#report f
+
 type 'a result =
     | Done of 'a
     | Failed of F.t
     | Exn of exn
 
-let exec f =
-  begin try Done (f ()) with
+let exec f a =
+  begin try Done (f a) with
   | (Sys.Break | Signal _) as exn -> raise exn
   | Fail msg -> Failed msg
   | exn -> Exn exn
@@ -187,10 +203,14 @@ let hook f a h =
   end
 
 let timeout ?(seconds=2) f a h =
-  ignore (Unix.alarm seconds);
-  Sys.set_signal Sys.sigalrm (Sys.Signal_handle signal);
-  let start () = (try f a with Signal i when i = Sys.sigalrm -> h ()) in
-  hook start () (fun () ->
-    Sys.set_signal Sys.sigalrm Sys.Signal_ignore
-  )
+  begin match Sys.os_type with
+  | "Unix" | "Cygwin" ->
+      ignore (Unix.alarm seconds);
+      Sys.set_signal Sys.sigalrm (Sys.Signal_handle signal);
+      let start () = (try f a with Signal i when i = Sys.sigalrm -> h ()) in
+      hook start () (fun () ->
+        Sys.set_signal Sys.sigalrm Sys.Signal_ignore
+      )
+  | _ -> f a
+  end
 
