@@ -1,6 +1,6 @@
 
 (*
- * Copyright (C) 2007-2009 The laby team
+ * Copyright (C) 2007-2010 The laby team
  * You have permission to copy, modify, and redistribute under the
  * terms of the GPL-3.0. For full license terms, see gpl-3.0.txt.
  *)
@@ -35,10 +35,13 @@ let no_exit =
 let carry_exit =
   F.x "I can't go out carrying a rock." []
 
-let rock_no_take =
+let take_nothing =
   F.x "There's no rock to take here." []
 
-let rock_no_drop =
+let drop_nothing =
+  F.x "I have nothing to drop." []
+
+let drop_no_space =
   F.x "I can't drop the rock here." []
 
 let action f =
@@ -54,8 +57,9 @@ let action f =
   | `Exit -> f exit
   | `No_Exit -> f no_exit
   | `Carry_Exit -> f carry_exit
-  | `Rock_No_Take -> f rock_no_take
-  | `Rock_No_Drop -> f rock_no_drop
+  | `Take_Nothing -> f take_nothing
+  | `Drop_Nothing -> f drop_nothing
+  | `Drop_No_Space -> f drop_no_space
   | `Say s -> f (F.s s)
   end
 
