@@ -1,6 +1,6 @@
 
 (*
- * Copyright (C) 2007-2009 The laby team
+ * Copyright (C) 2007-2010 The laby team
  * You have permission to copy, modify, and redistribute under the
  * terms of the GPL-3.0. For full license terms, see gpl-3.0.txt.
  *)
@@ -14,7 +14,7 @@ type action =
  | `Web_Out
  | `Exit | `No_Exit | `Carry_Exit
  | `Rock_Take | `Rock_Drop
- | `Rock_No_Take | `Rock_No_Drop
+ | `Take_Nothing | `Drop_Nothing | `Drop_No_Space
  | `Say of string
  ]
 
@@ -142,19 +142,21 @@ let run action state =
             carry = `Rock;
 	    action = `Rock_Take;
 	  }
-      |  _, _ -> "error", chg state `Rock_No_Take
+      |  _, _ -> "error", chg state `Take_Nothing
       end
   | "drop" ->
       begin match state.carry, get state (front state) with
       | `Rock, `Void
-      | `Rock, `Web ->
+      | `Rock, `Web
+      | `Rock, `NWeb ->
 	  "ok",
 	  { state with
             map = set state (front state) `Rock;
             carry = `None;
 	    action = `Rock_Drop;
 	  }
-      |  _, _ -> "error", chg state `Rock_No_Drop
+      | `None, _ -> "error", chg state `Drop_Nothing
+      |  _, _ -> "error", chg state `Drop_No_Space
       end
   | a when String.length a > 4 && String.sub a 0 4 = "say " ->
       "ok", chg state (`Say (String.sub a 4 (String.length a - 4)))
