@@ -1,6 +1,6 @@
 
 (*
- * Copyright (C) 2007-2009 The laby team
+ * Copyright (C) 2007-2010 The laby team
  * You have permission to copy, modify, and redistribute under the
  * terms of the GPL-3.0. For full license terms, see gpl-3.0.txt.
  *)
@@ -14,7 +14,7 @@ type action =
  | `Web_Out
  | `Exit | `No_Exit | `Carry_Exit
  | `Rock_Take | `Rock_Drop
- | `Rock_No_Take | `Rock_No_Drop
+ | `Take_Nothing | `Drop_Nothing | `Drop_No_Space
  | `Say of string
  ]
 
@@ -27,7 +27,7 @@ val run : string -> t -> string * t
 
 val iter_map : t -> (int -> int -> tile -> unit) -> unit
 val pos : t -> int * int
-val carry : t -> [`None | `Rock ]
+val carry : t -> [ `None | `Rock ]
 val dir : t -> dir
 val action : t -> action
 
